aboutsummaryrefslogtreecommitdiff
path: root/src/nvim/regexp.c
diff options
context:
space:
mode:
authorzeertzjq <zeertzjq@outlook.com>2022-11-05 11:27:28 +0800
committerzeertzjq <zeertzjq@outlook.com>2022-11-05 11:36:22 +0800
commit199c7c28989a3c36447ef56b71c7b84756950a11 (patch)
treeedf413e2f839c19f48dcd93be5c76afa0cf597e3 /src/nvim/regexp.c
parent45ca7d4a62d9d6275339e9d9c0a4930448592712 (diff)
downloadrneovim-199c7c28989a3c36447ef56b71c7b84756950a11.tar.gz
rneovim-199c7c28989a3c36447ef56b71c7b84756950a11.tar.bz2
rneovim-199c7c28989a3c36447ef56b71c7b84756950a11.zip
vim-patch:8.2.0612: Vim9: no check for space before #comment
Problem: Vim9: no check for space before #comment. Solution: Add space checks. https://github.com/vim/vim/commit/2c5ed4e3300378ce76c8d9c3818d6f73e5119f68 Omit ends_excmd2(): the same as ends_excmd() in legacy Vim script. Co-authored-by: Bram Moolenaar <Bram@vim.org>
Diffstat (limited to 'src/nvim/regexp.c')
-rw-r--r--src/nvim/regexp.c19
1 files changed, 16 insertions, 3 deletions
diff --git a/src/nvim/regexp.c b/src/nvim/regexp.c
index 4ae7fc7578..68ffc70457 100644
--- a/src/nvim/regexp.c
+++ b/src/nvim/regexp.c
@@ -481,12 +481,25 @@ static char_u *skip_anyof(char *p)
}
/// Skip past regular expression.
/// Stop at end of "startp" or where "dirc" is found ('/', '?', etc).
/// Take care of characters with a backslash in front of it.
/// Skip strings inside [ and ].
-char *skip_regexp(char *startp, int dirc, int magic)
+char *skip_regexp(char *startp, int delim, int magic)
{
- return skip_regexp_ex(startp, dirc, magic, NULL, NULL);
+ return skip_regexp_ex(startp, delim, magic, NULL, NULL);
+}
+
+/// Call skip_regexp() and when the delimiter does not match give an error and
+/// return NULL.
+char *skip_regexp_err(char *startp, int delim, int magic)
+{
+ char *p = skip_regexp(startp, delim, magic);
+
+ if (*p != delim) {
+ semsg(_("E654: missing delimiter after search pattern: %s"), startp);
+ return NULL;
+ }
+ return p;
}
/// skip_regexp() with extra arguments:
@@ -481,12 +481,25 @@ static char_u *skip_anyof(char *p)
}
/// Skip past regular expression.
-/// Stop at end of "startp" or where "dirc" is found ('/', '?', etc).
+/// Stop at end of "startp" or where "delim" is found ('/', '?', etc).
/// Take care of characters with a backslash in front of it.
/// Skip strings inside [ and ].